#
# spec file for package python-avro
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-avro
VCS: https://src.suse.de/SLFO-pool/python-avro#2c474221f2fb38b7e161ff6fe3f4625f9c72f8fe73fccfe230c87db1e2d00d0e
Version:        1.12.0
Release:        160000.1.4
Summary:        A serialization and RPC framework for Python
License:        Apache-2.0
URL:            https://avro.apache.org/
Source:         https://files.pythonhosted.org/packages/source/a/avro/avro-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Apache Avro is a serialization and RPC framework.
This package contains the python implementation of Avro.

%prep
%autosetup -p1 -n avro-%{version}
sed -i '1{\@^#!/usr/bin/env python@d}' avro/*.py avro/tether/*.py avro/test/*.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/avro
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Only contains test_server_with_path; tries to connect to apache.org
rm avro/test/test_ipc.py
%pyunittest discover -v

%post
%python_install_alternative avro

%postun
%python_uninstall_alternative avro

%files %{python_files}
%python_alternative %{_bindir}/avro
%{python_sitelib}/avro
%{python_sitelib}/avro-%{version}.dist-info

%changelog
* Tue Aug 27 2024 steven.kowalik@suse.com
- Update to 1.12.0:
  * Bug fixes:
    + [AVRO-1318]: Python schema should store fingerprints
    + [AVRO-3622]: Python compatibility check fails if record with and
    without namespace are compared
    + [AVRO-3659]: Typo in python example
    + [AVRO-3667]: [Python] Python 3.10 CI test fails since a while
    + [AVRO-3669]: Missing py.typed file
    + [AVRO-3861]: [Build] Add RAT exclusions for python docs
    + [AVRO-3866]: [Build][Python] Files are leftover after a build
  * Improvements:
    + [AVRO-312]: Generate documentation for Python with Sphinx
    + [AVRO-1938]: Python support for generating canonical forms of schema
    + [AVRO-3879]: [Build][Python] Fix ./build.sh clean to remove the
    generated Python documents
    + [AVRO-3977]: Fix failing typecheck in Python 3.12
  * Tests:
    + [AVRO-3696]: [Python] Replace tox-wheel with upstream tox 4
  * Tasks:
    + [AVRO-3808]: Drop support for Python 3.6, add Pypy 3.8-3.10
- Switch to pyproject and pyunittest macros.
* Thu Mar  7 2024 adrian.glaubitz@suse.com
- Switch package to modern Python Stack on SLE-15
  + Add %%{?sle15_python_module_pythons}
  + Drop %%define skip_python2 1
* Wed Oct 18 2023 dimstar@opensuse.org
- Update to version 1.11.3:
  + See jira board for all the fixes addressed in this release:
    https://issues.apache.org/jira/browse/AVRO-3855?jql=project%%3DAVRO%%20AND%%20fixVersion%%3D1.11.3
- Drop py311.patch: fixed upstream.
* Wed Jan 25 2023 daniel.garcia@suse.com
- Add py311.patch to make tests compatible with python 3.11 gh#apache/avro#1961
* Thu Aug  4 2022 otto.hollmann@suse.com
- Update to 1.11.1 (from GitHub release notes):
  - Avro specification
  - Clarify which names are allowed to be qualified with
    namespaces
  - Inconsistent behaviour on types as invalid names
  - Clarify how fullnames are created, with example
  - IDL: add syntax to create optional fields
  - Improve docs for logical type annotation
  - Python
  - Scale assignment optimization
  - "Scale" property from decimal object
  - Byte reading in avro.io does not assert bytes read
  - validate the default value of an enum field
  - Pass LogicalType to BytesDecimalSchema
  - Website
  - Website refactor
  - Document IDL support in IDEs
* Tue Nov 16 2021 guillaume.gardet@opensuse.org
- Disable test_minimum_speed which is unstable in OBS
* Wed Nov  3 2021 adrian.glaubitz@suse.com
- Update to 1.11.0
  * Improved performance validating deep record data
  * Drop Python 2 support
  * Drop Python 3.5 support
  * The avro package fully supports Python 3. We will no
    longer publish a separate avro-python3 package
- Disable Python2 builds
* Fri Apr 16 2021 mmachova@suse.com
- update to 1.10.2
  * Python: AVRO-2656 The standard avro package supports Python 3, and
    the avro-python3 package is in the process of being deprecated.
  * Threading.is_alive Spelling for Py3.9
* Mon Jan 18 2021 dmueller@suse.com
- update to 1.10.1:
  * AVRO-2889 python tether test is flaky
* Sat Jul 11 2020 code@bnavigator.de
- Update to version 1.10.0
  AVRO-2387 Type checking added to python
  AVRO-2656 avro-python package is now the preferred python3 library
  and avro-python3 is prepared to be deprecated
- reenable unit tests
- remove unnecessary BuildRequires for the linting packages
- add untested and not in setup.cfg declared but imported packages
  into Requires https://issues.apache.org/jira/browse/AVRO-2595
* Wed May 27 2020 pgajdos@suse.com
- %%python3_only -> %%python_alternative
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 1.9.2
  * no upstream changelog found
* Fri Sep 13 2019 tchvatal@suse.com
- Update to 1.9.0:
  * no upstream changelog
* Fri Jun 21 2019 pgajdos@suse.com
- version update to 1.9.0
  * no upstream changelog found
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Thu Nov 29 2018 jengelh@inai.de
- Avoid name repetition in summary.
* Thu Nov 29 2018 tbechtold@suse.com
- Initial packaging (version 1.8.2)
